@@ -80,7 +80,7 @@ class FunctionDefinition(object):
 
         #: name of the function argument to pass the host request object.
         #: Should be set by using the :class:`wsme.types.HostRequest` type
-        #: in the function @\ :function:`signature`
+        #: in the function @\ :func:`signature`
         self.pass_request = False
 
         #: Dictionnary of protocol-specific options.
@@ -179,7 +179,7 @@ class signature(object):
         fd.return_type = self.return_type
         fd.set_options(**self.options)
         if self.arg_types:
-                fd.set_arg_types(argspec, self.arg_types)
+            fd.set_arg_types(argspec, self.arg_types)
         return func
 
 
@@ -217,7 +217,8 @@ def format_exception(excinfo, debug=False):
     if code and utils.is_valid_code(code) and utils.is_client_error(code):
         faultstring = (error.faultstring if hasattr(error, 'faultstring')
                        else six.text_type(error))
-        r = dict(faultcode="Client",
+        faultcode = getattr(error, 'faultcode', 'Client')
+        r = dict(faultcode=faultcode,
                  faultstring=faultstring)
         log.debug("Client-side error: %s" % r['faultstring'])
         r['debuginfo'] = None
@@ -229,7 +230,8 @@ def format_exception(excinfo, debug=False):
         log.error('Server-side error: "%s". Detail: \n%s' % (
             faultstring, debuginfo))
 
-        r = dict(faultcode="Server", faultstring=faultstring)
+        faultcode = getattr(error, 'faultcode', 'Server')
+        r = dict(faultcode=faultcode, faultstring=faultstring)
         if debug:
             r['debuginfo'] = debuginfo
         else:
