@@ -10,7 +10,6 @@ import webob
 from wsme.exc import ClientSideError, UnknownFunction
 from wsme.protocol import getprotocol
 from wsme.rest import scan_api
-from wsme import spore
 import wsme.api
 import wsme.types
 
@@ -232,11 +231,6 @@ class WSRoot(object):
             res.content_type = func._cfg['content-type']
             return res
 
-        if request.path == self._webpath + '/api.spore':
-            res.body = spore.getdesc(self, request.host_url)
-            res.content_type = 'application/json'
-            return res
-
         try:
             msg = None
             error_status = 500
@@ -317,7 +311,11 @@ class WSRoot(object):
             # Attempt to correctly guess what content-type we should return.
             ctypes = [ct for ct in protocol.content_types if ct]
             if ctypes:
-                res_content_type = request.accept.best_match(ctypes)
+                try:
+                    offers = request.accept.acceptable_offers(ctypes)
+                    res_content_type = offers[0][0]
+                except IndexError:
+                    res_content_type = None
 
         # If not we will attempt to convert the body to an accepted
         # output format.
