@@ -1,21 +1,15 @@
 import base64
 import datetime
 import decimal
+import json
 
-import wsme.tests.protocol
-
-try:
-    import simplejson as json
-except ImportError:
-    import json  # noqa
-
-from wsme.rest.json import fromjson, tojson, parse
-from wsme.utils import parse_isodatetime, parse_isotime, parse_isodate
+from wsme.exc import ClientSideError, InvalidInput
 from wsme.types import isarray, isdict, isusertype, register_type
 from wsme.types import UserType, ArrayType, DictType
 from wsme.rest import expose, validate
-from wsme.exc import ClientSideError, InvalidInput
-
+from wsme.rest.json import fromjson, tojson, parse
+import wsme.tests.protocol
+from wsme.utils import parse_isodatetime, parse_isotime, parse_isodate
 
 import six
 from six import b, u
