@@ -135,6 +135,7 @@ class BinaryType(UserType):
             return None
         return base64.decodestring(value)
 
+
 #: The binary almost-native type
 binary = BinaryType()
 
@@ -325,6 +326,7 @@ class UnsetType(object):
     def __repr__(self):
         return 'Unset'
 
+
 Unset = UnsetType()
 
 #: A special type that corresponds to the host framework request object.
@@ -487,7 +489,7 @@ class wsattr(object):
     def __set__(self, instance, value):
         try:
             value = validate_value(self.datatype, value)
-        except ValueError as e:
+        except (ValueError, TypeError) as e:
             raise exc.InvalidInput(self.name, value, six.text_type(e))
         dataholder = self._get_dataholder(instance)
         if value is Unset:
@@ -741,6 +743,7 @@ class Registry(object):
             type_ = self.register(type_)
         return type_
 
+
 # Default type registry
 registry = Registry()
 
