@@ -5,22 +5,22 @@ import logging
 import sys
 import inspect
 
+import flask
+
 import wsme
 import wsme.api
+import wsme.rest.args
 import wsme.rest.json
 import wsme.rest.xml
-import wsme.rest.args
 from wsme.utils import is_valid_code
 
-import flask
-
 log = logging.getLogger(__name__)
 
 
 TYPES = {
     'application/json': wsme.rest.json,
     'application/xml': wsme.rest.xml,
-    'text/xml': wsme.rest.xml
+    'text/xml': wsme.rest.xml,
 }
 
 
@@ -35,8 +35,8 @@ def get_dataformat():
     if req_dataformat in TYPES:
         return TYPES[req_dataformat]
 
-    log.info('''Could not determine what format is wanted by the
-             caller, falling back to json''')
+    log.info('Could not determine what format is wanted by the caller, '
+             'falling back to JSON')
     return wsme.rest.json
 
 
